@@ -1,15 +1,32 @@
-# builtin modules
-import sys
+###############################################################################
+# copyright 2010 Edwin Marshall (aspidites) <aspidties@inbox.com>             #
+#                                                                             #
+# This file is part of MaeGym                                                 #
+#                                                                             #
+# MaeGym is free software: you can redistribute it and/or                     #
+# modify it under the terms of the GNU General Public License as published by #
+# the Free Software Foundation, either version 3 of the License, or           #
+# (at your option) any later version.                                         #
+#                                                                             #
+# MaeGym is distributed in the hope that it will be useful,                   #
+# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
+# GNU General Public License for more details.                                #
+#                                                                             #
+# You should have received a copy of the GNU General Public License           #
+# along with MaeGym.                                                          # 
+# If not, see <http://www.gnu.org/licenses/>.                                 #
+###############################################################################
 
 # pyqt modules
 from PyQt4.QtGui import (QInputDialog, QLineEdit, QMainWindow, QMenu)
-from PyQt4.QtCore import (pyqtSignature, Qt, SIGNAL)
+from PyQt4.QtCore import (pyqtSignature, Qt)
 
 # third-party modules
 import config as c
 
 # program modules 
-from database import Database
+#from database import Database
 from ui.ui_target_areas_window import Ui_TargetAreasWindow
 import routines_window as ww
 import exercises_window as ew
@@ -30,8 +47,7 @@ class TargetAreasWindow(QMainWindow, Ui_TargetAreasWindow):
 
     @pyqtSignature("QModelIndex")
     def on_target_areas_list_view_clicked(self, index):
-        t_name = self.db.target_areas_model.record(index.row()).value('t_name').toString()
-
+        t_name = index.data().toString()
         filtered_exercises_window = ew.ExercisesWindow(self, self.db, t_name)
         filtered_exercises_window.show()
 
@@ -55,13 +71,11 @@ class TargetAreasWindow(QMainWindow, Ui_TargetAreasWindow):
     def on_new_target_area_button_pressed(self):
         def updateTName(text):
             global t_name
-
             t_name = text
 
         def addTargetArea():
             global t_name
-
-            self.db.addTargetArea(t_name)
+            self.db.editTargetArea(t_name)
 
         dialog = QInputDialog(self)
         dialog.setWindowTitle('New Target Area')
@@ -69,10 +83,8 @@ class TargetAreasWindow(QMainWindow, Ui_TargetAreasWindow):
         dialog.setOkButtonText('Save')
         t_name = None
         
-        self.connect(dialog, SIGNAL('textValueChanged(QString)'),
-                     updateTName)
-
-        self.connect(dialog, SIGNAL('accepted()'), addTargetArea)
+        dialog.textValueChanged.connect(updateTName)
+        dialog.accepted.connect(addTargetArea)
         dialog.show()
 
 
@@ -102,11 +114,8 @@ class TargetAreasWindow(QMainWindow, Ui_TargetAreasWindow):
             t_name = None
             old_name = dialog.textValue()
 
-            self.connect(dialog, SIGNAL('textValueChanged(QString)'),
-                         updateTName)
-
-            self.connect(dialog, SIGNAL("accepted()"), editTargetArea)
-
+            dialog.textValueChanged.connect(updateTName)
+            dialog.accepted.connect(editTargetArea)
             dialog.show()
         elif action == delete_action:
             self.db.target_areas_model.removeRow(
